Module firecracker

Module firecracker 

Functions

download_assets
Download kernel and rootfs into ~/microvm/ inside the Lima VM.
install
Install Firecracker inside the Lima VM.
is_installed
Check if Firecracker is installed inside the Lima VM.
is_running
Check if the Firecracker process is running inside the Lima VM.
is_vm_running
Check if a specific VM’s Firecracker process is alive (by PID file path). Uses /proc//comm instead of kill -0 because firecracker runs as root.
prepare_rootfs
Prepare the ext4 root filesystem from the downloaded squashfs.
validate_rootfs_squashfs
Check whether the downloaded squashfs file is intact.
write_state
Write the state file with discovered asset filenames.