Skip to main content Module shell Copy item path Source inside_lima Heuristic: are we currently executing inside a Lima guest VM?
Checks common Lima environment markers. replace_process Replace the current process with an interactive command (for SSH/TTY).
Uses Unix exec() — the Rust process is fully replaced, no return on success.
Note: This is safe because all arguments are passed as an array, not via shell interpolation. run_host Run a command on the host, capturing output. run_host_visible Run a command on the host, inheriting stdio (visible to user). run_in_vm Run a bash script in the default execution environment, capturing output. run_in_vm_stdout Run a bash script in the default execution environment, returning stdout as String. run_in_vm_visible Run a bash script in the default execution environment, with output visible to user. run_on_vm Run a bash script in the Linux execution environment, capturing output. run_on_vm_stdout Run a bash script in the Linux execution environment, returning stdout as String. run_on_vm_visible Run a bash script in the Linux execution environment, with output visible to user.